Export updated key quantities template

export_kqs(...)

Arguments

...

Key quantities whose values should be added to the exported "key_quantities.csv"

Value

Exports a file based on key quantities template, with values added next to the names of the key quantities specified as ellipsis arguments. File is saved as "key_quantities.csv" to the working directory.

See also

[fill_in_kqs()], [insert_kqs()]

Examples

if (FALSE) { # \dontrun{
export_kqs(
  F.min,
  F.max
)
} # }