Substitute key quantities' values into template

fill_in_kqs(df, ...)

Arguments

df

Dataframe created by importing "key_quantity_template.csv" or "key_quantities.csv", empty or partially-filled templates with key quantity names and other associated information

...

Key quantity objects whose values will be added to the output dataframe

Value

Dataframe based on key quantities template that contains newly-added values of key quantities indicated via ellipsis.

Details

The returned dataframe is input for [fill_in_kqs()].

See also

[export_kqs()], [insert_kqs()]

Examples

if (FALSE) { # \dontrun{
fill_in_kqs(
  df = data,
  F.min,
  F.max
)
} # }