Show all tables and figures in a single html file.

html_all_figs_tables(figures_tables_dir = getwd())

Arguments

figures_tables_dir

The location of the folder containing figures and tables ("figures" and "tables").

Default: The current working directory (`getwd()`)

Value

A folder ("all_tables_figures") in your working directory containing html and qmd files that show all tables and figures.

See also

asar::create_figures_doc(), asar::create_tables_doc()

Examples

if (FALSE) { # \dontrun{
html_all_figs_tables()
html_all_figs_tables(figures_tables_dir = "my_figures_tables_dir")
} # }