Insert key quantities into the captions and alternative text file

insert_kqs(...)

Arguments

...

Key quantities whose values should be added to the exported "captions_alt_text.csv"

Value

Exports a file ("captions_alt_text.csv") containing captions and alternative text for figures and tables, with key quantities inserted into the "captions_alt_text_template.csv" template's placeholders.

Examples

if (FALSE) { # \dontrun{
insert_kqs(
  F.min,
  F.max)
} # }