R/utils_table.R
merge_error.RdRename columns and merge estimate and uncertainty columns for table presentation
merge_error(table_data, id_col_vals, unit_label, uncert_lab)list of dataframes that will be eventually turned into tables
A list of variables identifying grouping of the data and their unique values.
String. The units of the estimate being presented in the table.
uncertainty label. Typically inherited from another function but is the exact string of the uncertainty in the data (e.g., "sd", "se", "cv", "uncertainty").)
List of formatted dataframes that contain column names formatted for a table along with a merge of values in the estimate and error columns to reduce redundancy in the table.