Create "at-age" plot
plot_aa(
dat,
x = "year",
y = "age",
z = "estimate",
label = "Abundance",
xlab = "Year",
ylab = "Age",
facet = NULL,
proportional = TRUE,
...
)Data frame. Filtered data frame from standard output file(s) preformatted for the target label from filter_data
String. Column name of data used to plot on the x-axis
Default: "year"
String. Column name of data used to plot on the y-axis
Default: "age"
String. Column name of data used to control the size of the bubbles
Default: "estimate"
String. Label for the size of the bubbles
Default: "Abundance"
String. X-axis label
Default: "Year"
String. Y-axis label
Default: "Age"
Character vector. Column name or names used for faceting. It is not recommended to include more than one facet due to the complexity of the plot.
Default: NULL
Options: Including, but not limited to: "sex", "area", "fleet"
Logical. TRUE/FALSE; set size of points relative to z when TRUE, point size are relative to one another while when set to FALSE, point size is relative to z
Default: `TRUE`
Inherited arguments from internal functions from geom_point
Create a plot of abundance at age for a stock assessment report.
if (FALSE) { # \dontrun{
plot_aa(dat)
} # }