Plot Abundance at Age
plot_abundance_at_age(
dat,
facet = NULL,
unit_label = "fish",
scale_amount = 1000,
proportional = TRUE,
module = NULL,
interactive = TRUE,
make_rda = FALSE,
figures_dir = getwd()
)Data frame. A data frame returned from convert_output
Character vector. Column name or names used for faceting. Set facet = "none" to summarize the data in a single plot.
Default: NULL
Options: Including, but not limited to: "year", "area", "fleet", "sex", "none", NULL
String. Abundance units
Default: "fish"
Number. A number describing how much to scale down the abundance at age. Please choose a value ranging from 1-1,000,000,000 (one billion) in orders of magnitude (e.g., 1, 10, 100, 1000, etc.). For example, scale_amount = 100 would scale down a value from 500,000 –> 5,000 and would report abundance in hundreds of fish (if "fish" was the unit_label). This scale will be reflected in the legend label if proportional is set to FALSE.
Default: 1,000
Logical. TRUE/FALSE; set size of points relative to z when TRUE, point size are relative to one another while when set to FALSE, point size is relative to z
Default: `TRUE`
(Optional) A string indicating the module_name found in `dat`. If selecting >1 module, place them in a vector like c("module1", "module2").
Default: NULL
If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]
A logical value indicating if the environment is interactive.
Default: `FALSE`
Logical. TRUE/FALSE; indicate whether to produce an .rda file containing a list with the figure/table, caption, and alternative text (if figure). If TRUE, the .rda will be exported to the folder indicated in the argument "rda_dir".
Default: `FALSE`
Path. Folder containing the generated .rda files ("rda_files") that will be created if the argument `make_rda` = TRUE.
Default: the working directory (`getwd()`)
A plot showing total abundance (or numbers) at age.
The input is from an assessment model output file translated to a standardized output (convert_output). There are options to return a `ggplot2` object or export an .rda object containing associated caption and alternative text for the figure.
[convert_output()], [filter_data()], [process_data()], [plot_aa()], [export_kqs()], [insert_kqs()], [create_rda()]
plot_abundance_at_age(
dat = stockplotr:::example_data,
facet = "growth_pattern",
unit_label = "fish",
scale_amount = 1000,
proportional = TRUE
)
#> ! Multiple module names found in data.
#> ℹ Environment not interactive. Selecting NUMBERS_AT_AGE.
#> Joining with `by = join_by(year, sex, growth_pattern)`
plot_abundance_at_age(
dat = stockplotr:::example_data,
facet = "none",
proportional = FALSE
)
#> ! Multiple module names found in data.
#> ℹ Environment not interactive. Selecting NUMBERS_AT_AGE.
#> Joining with `by = join_by(year)`