Plot Index of Abundance

plot_indices(
  dat,
  unit_label = "",
  group = NULL,
  facet = NULL,
  interactive = TRUE,
  module = NULL,
  focus = NULL,
  make_rda = FALSE,
  figures_dir = getwd(),
  ...
)

Arguments

dat

A tibble or named list of tibbles (input as `list()`) returned from convert_output.

If inputting a list of tibbles, the first tibble's reference point defined in `ref_line` is used to plot a reference line or calculate relative spawning biomass.

unit_label

units for index of abundance/CPUE

Default: ""

group

A string of a single column that groups the data.

Set group = "none" to summarize data over all indexing values.

Default: NULL Options: Including, but not limited to: "year", "area", "fleet", "sex", "none", NULL

facet

a string or vector of strings of a column that facets the data. "fleet" is always added on to any faceting selections

Default: NULL

Options: May include, but is not limited to: "fleet", "year", "area", NULL

interactive

A logical value indicating if the environment is interactive.

Default: `FALSE`

module

(Optional) A string indicating the module_name found in `dat`. If selecting >1 module, place them in a vector like c("module1", "module2").

Default: NULL

If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]

focus

a string or vector of strings indicating how data should be filtered. (i.e. select names of fleets to zoom into the plot)

Default: NULL

make_rda

A logical value indicating whether to save the object and make an automated caption and alternative text in the form of an `rda` object. If TRUE, the rda will be exported to the folder indicated in the argument "figures_dir".

Default: `FALSE`.

figures_dir

A string indicating a path to the "figures" folder.

Default: `getwd()`

The folder is created within the path if it does not exist.

...

Arguments called from geom_line or geom_point

Value

A plot showing the expected and predicted indices.

Details

The input is from an assessment model output file translated to a standardized output (convert_output). There are options to return a `ggplot2` object or export an .rda object containing associated caption and alternative text for the figure.

See also

[convert_output()], [filter_data()], [process_data()], [plot_obsvpred()], [export_kqs()], [insert_kqs()], [create_rda()]

Examples

plot_indices(
  dat = stockplotr:::example_data,
  unit_label = "fish/hr",
  interactive = FALSE
)
#> Scale for x is already present.
#> Adding another scale for x, which will replace the existing scale.