Plot observed vs. predicted data
plot_obsvpred(
dat,
x = "year",
y = "estimate",
observed_label = "observed",
predicted_label = "predicted",
geom = "line",
xlab = "Year",
ylab = NULL,
group = NULL,
facet = NULL
)Data frame. Filtered data frame from standard output file(s) preformatted for the target label from filter_data
String. Column name of data used to plot on the x-axis
Default: "year"
String. Column name of data used to plot on the y-axis
Default: "estimate"
String. Label used to filter the observed data
Default: "observed"
String. Label used to filter the predicted data Default: "predicted"
String. Type of geom to use for plotting found in ggplot2 (e.g. "point", "line", etc.).
Default: "line"
Options: "point" and "area"
String. X-axis label
Default: "Year"
String. Y-axis label. If NULL, it will be set to the name of `y`.
Default: NULL
String. Single column that groups the data. Currently can only have one level of grouping.
Default: NULL Options: Including, but not limited to: "year", "area", "fleet", "sex", "none", NULL
Character vector. Column name or names used for faceting (e.g. "year", "area", etc.)
Default: NULL
A plot of observed vs. predicted data for a stock assessment report.