Plot Recruitment Deviations
plot_recruitment_deviations(
dat,
module = NULL,
era = "time",
interactive = TRUE,
make_rda = FALSE,
figures_dir = getwd(),
...
)A tibble or named list of tibbles (input as `list()`) returned from convert_output.
If inputting a list of tibbles, the first tibble's reference point defined in `ref_line` is used to plot a reference line or calculate relative spawning biomass.
(Optional) A string indicating the module_name found in `dat`.
Default: NULL
If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]
A string naming the era of data.
Default: "time"
Options: "early", "time", "fore" (forecast), or NULL (all data)
A logical value indicating if the environment is interactive.
Default: `FALSE`
A logical value indicating whether to save the object and make an automated caption and alternative text in the form of an `rda` object. If TRUE, the rda will be exported to the folder indicated in the argument "figures_dir".
Default: `FALSE`.
A string indicating a path to the "figures" folder.
Default: `getwd()`
The folder is created within the path if it does not exist.
Arguments called from geom_line or geom_point
Plot recruitment deviations relative to one over time from an assessment model output file translated to a standardized output (convert_output). There are options to return a `ggplot2` object or export an .rda object containing associated caption and alternative text for the figure.
plot_recruitment_deviations(
dat = stockplotr:::example_data,
interactive = FALSE,
size = 1.5
)
#> ! Multiple module names found in data.
#> ℹ Environment not interactive. Selecting PARAMETERS.
#> Ignoring unknown labels:
#> • colour : "Model"
plot_recruitment_deviations(
dat = stockplotr:::example_data,
era = "early",
interactive = FALSE,
shape = 2
)
#> ! Multiple module names found in data.
#> ℹ Environment not interactive. Selecting PARAMETERS.
#> Ignoring unknown labels:
#> • colour : "Model"