Format stock assessment output files to a standardized format.
convert_output(file, model = NULL, fleet_names = NULL, save_dir = NULL)Assessment model output file path
Assessment model used in evaluation ("ss3", "bam", "fims").
Names of fleets in the assessment model as shortened in the output file. If fleet names are not properly read, then indicate the fleets names as an acronym in a vector
File path to save the converted output file.
A reformatted and standardized version of assessment model results for application in building a stock assessment reports and to easily adapt results among regional assessments. The resulting object is simply a transformed and machine readable version of a model output file. Converted data frame is always returned. It will also be saved if save_dir is not NULL.