Included data set that represents a Report.sso file converted using convert_output(). This example is from the 2022 Petrale sole stock assessment.

example_data

Format

A tibble with 591109 rows and 33 variables:

label

standard name for estimate or value name

estimate

actual value of the label

year

annual indexing value

fleet

names of fleets or surveys indexed by the data

sex

native reference to male, female, unknown, or none

area

specified areas by the model

growth_pattern

indexing column of data

uncertainty

value of uncertainty associated with the label column

uncertainty_label

uncertainty label or name associated with the label columns

module_name

name of keyword (SS3) or list indexing in the original model output for tracking purposes

time

time sometimes referenced in decimals to the year and month

era

"time" for current time series in model; "fore" representing the projected or forecasted years of the model

month

month factor

season

season usually associated with year

subseason

subseason when used

birthseas

birthseason found in SS3

initial

initial input value in the model when available associated with the label column

likelihood

likelihood value for the data point

platoon

platoon also an SS3 indexing value

age

age of fish

bio_pattern

indexing column of data

settlement

indexing column of data

morph

indexing column of data

type

indexing column of data

factor

indexing column of data

part

indexing column of data

kind

indexing column of data

nsim

indexing column of data

bin

indexing column of data

age_a

alternative age column

length_bins

length bins for composition or other length based data

count

indexing column of data

block

indexing column of data