Included data set that represents a Report.sso file converted using convert_output(). This example is from the 2022 Petrale sole stock assessment.
example_dataA tibble with 591109 rows and 33 variables:
standard name for estimate or value name
actual value of the label
annual indexing value
names of fleets or surveys indexed by the data
native reference to male, female, unknown, or none
specified areas by the model
indexing column of data
value of uncertainty associated with the label column
uncertainty label or name associated with the label columns
name of keyword (SS3) or list indexing in the original model output for tracking purposes
time sometimes referenced in decimals to the year and month
"time" for current time series in model; "fore" representing the projected or forecasted years of the model
month factor
season usually associated with year
subseason when used
birthseason found in SS3
initial input value in the model when available associated with the label column
likelihood value for the data point
platoon also an SS3 indexing value
age of fish
indexing column of data
indexing column of data
indexing column of data
indexing column of data
indexing column of data
indexing column of data
indexing column of data
indexing column of data
indexing column of data
alternative age column
length bins for composition or other length based data
indexing column of data
indexing column of data