Export updated key quantities template
export_kqs(...)Exports a file based on key quantities template, with values added next to the names of the key quantities specified as ellipsis arguments. File is saved as "key_quantities.csv" to the working directory.
if (FALSE) { # \dontrun{
export_kqs(
F.min,
F.max)
} # }