Create "at-age" plot

plot_aa(
  dat,
  x = "year",
  y = "age",
  z = "estimate",
  label = "Abundance",
  xlab = "Year",
  ylab = "Age",
  facet = NULL,
  proportional = TRUE,
  ...
)

Arguments

dat

filtered data frame from standard output file(s) preformatted for the target label from filter_data

x

a string of the column name of data used to plot on the x-axis

Default: "year"

y

a string of the column name of data used to plot on the y-axis

Default: "age"

z

a string of the column name of data used to control the size of the bubbles

Default: "estimate"

label

a string of the label for the size of the bubbles

Default: "Abundance"

xlab

a string of the x-axis label

Default: "Year"

ylab

a string of the y-axis label

Default: "Age"

facet

a string or vector of strings of a column that facets the data. It is not recommended to include more than one facet due to the complexity of the plot.

Default: NULL

Options: Including, but not limited to: "sex", "area", "fleet"

proportional

Set size of points relative to z when TRUE, point size are relative to one another while when set to FALSE, point size is relative to z

Default: `TRUE`

...

inherited arguments from internal functions from geom_point

Value

Create a plot of abundance at age for a stock assessment report.

Examples

if (FALSE) { # \dontrun{
plot_aa(dat)
} # }