Plot observed landings

plot_landings(
  dat,
  unit_label = "metric tons",
  geom = "line",
  group = NULL,
  facet = NULL,
  era = NULL,
  scale_amount = 1,
  module = NULL,
  interactive = TRUE,
  make_rda = FALSE,
  figures_dir = getwd(),
  ...
)

Arguments

dat

A tibble or named list of tibbles (input as `list()`) returned from convert_output.

If inputting a list of tibbles, the first tibble's reference point defined in `ref_line` is used to plot a reference line or calculate relative spawning biomass.

unit_label

A string specifying spawning biomass unit.

Default: "metric tons"

geom

A string stating the geom used for the plot.

Default: "line".

Options: "line", "point", or "area"

group

A string of a single column that groups the data (e.g. "fleet", "sex", "area", etc.).

Set group = "none" to summarize data over all indexing values.

Default: NULL

facet

A string or vector of strings of a column name.

Default: NULL

era

A string naming the era of data.

Default: "time"

Options: "early", "time", "fore" (forecast), or NULL (all data)

scale_amount

A number to scale the y-axis values.

Default: 1

module

(Optional) A string indicating the module_name found in `dat`.

Default: NULL

If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]

interactive

A logical value indicating if the environment is interactive.

Default: `FALSE`

make_rda

A logical value indicating whether to save the object and make an automated caption and alternative text in the form of an `rda` object. If TRUE, the rda will be exported to the folder indicated in the argument "figures_dir".

Default: `FALSE`.

figures_dir

A string indicating a path to the "figures" folder.

Default: `getwd()`

The folder is created within the path if it does not exist.

...

Arguments called from geom_line or geom_point

Value

Create a plot ready for a stock assessment report of cumulative landings over time (convert_output). There are options to return a [ggplot2::ggplot()] object or export an rda object containing associated caption and alternative text for the figure.

Examples

plot_landings(
  dat = stockplotr:::example_data,
  unit_label = "metric tons",
  group = "fleet",
  interactive = FALSE,
  make_rda = FALSE
)
#> ! Multiple module names found in data. 
#>  Environment not interactive. Selecting CATCH.
#> Ignoring unknown labels:
#>  linetype : "Fleet"
#>  shape : "Fleet"

plot_landings(
  dat = stockplotr:::example_data,
  unit_label = "metric tons",
  facet = "fleet",
  interactive = FALSE,
  make_rda = FALSE
)
#> ! Multiple module names found in data. 
#>  Environment not interactive. Selecting CATCH.
#> Ignoring unknown labels:
#>  linetype : "Fleet"
#>  shape : "Fleet"