Plot natural mortality (M) at age
plot_natural_mortality(
dat,
group = NULL,
facet = NULL,
era = NULL,
interactive = TRUE,
module = NULL,
make_rda = FALSE,
figures_dir = getwd(),
...
)A tibble or named list of tibbles (input as `list()`) returned from convert_output.
If inputting a list of tibbles, the first tibble's reference point defined in `ref_line` is used to plot a reference line or calculate relative spawning biomass.
A string of a single column that groups the data (e.g. "fleet", "sex", "area", etc.).
Set group = "none" to summarize data over all indexing values.
Default: NULL
A string or vector of strings of a column name.
Default: NULL
A string naming the era of data.
Default: "time"
Options: "early", "time", "fore" (forecast), or NULL (all data)
A logical value indicating if the environment is interactive.
Default: `FALSE`
(Optional) A string indicating the module_name found in `dat`.
Default: NULL
If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]
A logical value indicating whether to save the object and make an automated caption and alternative text in the form of an `rda` object. If TRUE, the rda will be exported to the folder indicated in the argument "figures_dir".
Default: `FALSE`.
A string indicating a path to the "figures" folder.
Default: `getwd()`
The folder is created within the path if it does not exist.
Arguments called from geom_line or geom_point
Plot natural mortality at age from a stock assessment model as found in a NOAA stock assessment report.
plot_natural_mortality(
dat = stockplotr:::example_data,
module = "Natural_Mortality",
interactive = FALSE
)
#> Ignoring unknown labels:
#> • linetype : "Sex"
#> • shape : "Sex"