Plot observed vs. predicted data

plot_obsvpred(
  dat,
  x = "year",
  y = "estimate",
  observed_label = "observed",
  predicted_label = "predicted",
  geom = "line",
  xlab = "Year",
  ylab = NULL,
  group = NULL,
  facet = NULL,
  ...
)

Arguments

dat

filtered data frame from standard output file(s) preformatted for the target label from filter_data

x

a string of the column name of data used to plot on the x-axis

Default: "year"

y

a string of the column name of data used to plot on the y-axis

Default: "estimate"

observed_label

a string of the label used to filter the observed data

Default: "observed"

predicted_label

a string of the label used to filter the predicted data Default: "predicted"

geom

type of geom to use for plotting found in ggplot2 (e.g. "point", "line", etc.).

Default: "line"

Options: "point" and "area"

xlab

a string of the x-axis label

Default: "Year"

ylab

a string of the y-axis label. If NULL, it will be set to the name of `y`.

Default: NULL

group

a string of a single column that groups the data. Currently can only have one level of grouping.

Default: NULL Options: Including, but not limited to: "year", "area", "fleet", "sex", "none", NULL

facet

a string or vector of strings of a column that facets the data (e.g. "year", "area", etc.)

Default: NULL

...

inherited arguments from internal functions from ggplot2::geom_xx

Value

A plot of observed vs. predicted data for a stock assessment report.