Plot observed vs. predicted data

plot_obsvpred(
  dat,
  x = "year",
  y = "estimate",
  observed_label = "observed",
  predicted_label = "predicted",
  geom = "line",
  xlab = "Year",
  ylab = NULL,
  group = NULL,
  facet = NULL,
  ...
)

Arguments

dat

filtered data frame from standard output file(s) preformatted for the target label from filter_data

x

a string of the column name of data used to plot on the x-axis (default is "year")

y

a string of the column name of data used to plot on the y-axis (default is "estimate")

observed_label

a string of the label used to filter the observed data. Default is "observed".

predicted_label

a string of the label used to filter the predicted data. Default is "predicted".

geom

type of geom to use for plotting found in ggplot2 (e.g. "point", "line", etc.). Default is "line". Other options are "point" and "area".

xlab

a string of the x-axis label (default is "Year")

ylab

a string of the y-axis label. If NULL, it will be set to the name of `y`.

group

a string of a single column that groups the data (e.g. "fleet", "sex", "area", etc.). Currently can only have one level of grouping.

facet

a string or vector of strings of a column that facets the data (e.g. "year", "area", etc.)

...

inherited arguments from internal functions from ggplot2::geom_xx

Value

Create a plot of observed vs. predicted data for a stock assessment report.