Plot observed vs. predicted data
plot_obsvpred(
dat,
x = "year",
y = "estimate",
observed_label = "observed",
predicted_label = "predicted",
geom = "line",
xlab = "Year",
ylab = NULL,
group = NULL,
facet = NULL,
...
)filtered data frame from standard output file(s) preformatted for the target label from filter_data
a string of the column name of data used to plot on the x-axis (default is "year")
a string of the column name of data used to plot on the y-axis (default is "estimate")
a string of the label used to filter the observed data. Default is "observed".
a string of the label used to filter the predicted data. Default is "predicted".
type of geom to use for plotting found in ggplot2 (e.g. "point", "line", etc.). Default is "line". Other options are "point" and "area".
a string of the x-axis label (default is "Year")
a string of the y-axis label. If NULL, it will be set to the name of `y`.
a string of a single column that groups the data (e.g. "fleet", "sex", "area", etc.). Currently can only have one level of grouping.
a string or vector of strings of a column that facets the data (e.g. "year", "area", etc.)
inherited arguments from internal functions from ggplot2::geom_xx
Create a plot of observed vs. predicted data for a stock assessment report.