Plot Recruitment
plot_recruitment(
dat,
unit_label = "mt",
scale_amount = 1,
era = "time",
group = NULL,
facet = NULL,
interactive = TRUE,
module = NULL,
make_rda = FALSE,
figures_dir = getwd()
)A tibble or named list of tibbles (input as `list()`) returned from convert_output.
If inputting a list of tibbles, the first tibble's reference point defined in `ref_line` is used to plot a reference line or calculate relative spawning biomass.
units for recruitment
A number to scale the y-axis values.
Default: 1
A string naming the era of data.
Default: "time"
Options: "early", "time", "fore" (forecast), or NULL (all data)
A string of a single column that groups the data (e.g. "fleet", "sex", "area", etc.).
Set group = "none" to summarize data over all indexing values.
Default: NULL
A string or vector of strings of a column name.
Default: NULL
A logical value indicating if the environment is interactive.
Default: `FALSE`
(Optional) A string indicating the module_name found in `dat`.
Default: NULL
If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]
A logical value indicating whether to save the object and make an automated caption and alternative text in the form of an `rda` object. If TRUE, the rda will be exported to the folder indicated in the argument "figures_dir".
Default: `FALSE`.
A string indicating a path to the "figures" folder.
Default: `getwd()`
The folder is created within the path if it does not exist.
Plot recruitment over time from an assessment model output file translated to a standardized output (convert_output). There are options to return a [ggplot2::ggplot()] object or export an rda object containing associated caption and alternative text for the figure.
plot_recruitment(
dat = stockplotr:::example_data,
unit_label = "metric tons",
scale_amount = 100,
interactive = TRUE,
module = "TIME_SERIES",
make_rda = FALSE
)
#> Ignoring unknown labels:
#> • colour : "Model"
plot_recruitment(
dat = stockplotr:::example_data,
era = "fore",
module = "TIME_SERIES",
make_rda = FALSE
)
#> Ignoring unknown labels:
#> • colour : "Model"