Preformatted reference line
reference_line(
plot,
dat,
era = "time",
label_name,
reference,
relative = FALSE,
scale_amount = 1
)a ggplot2 object where the reference line will be added
standard data frame where reference point should be extracted
A string naming the era of data.
Default: "time"
Options: "early", "time", "fore" (forecast), or NULL (all data)
string of the name of the quantity that users want to extract the reference point from
string. name of the reference point such as "msy", "unfished", or "target"
A logical value specifying to set y-axis values relative to the ref_line value.
Default: `FALSE`
A number to scale the y-axis values.
Default: 1
a ggplot2 geom_hline object for a reference point that can be added to a plot
if (FALSE) { # \dontrun{
reference_line(dat, "biomass", "msy")
} # }