Generates a table showing assumed and projected years of Catch, SB, and F.
Data frame or list. A tibble or named list of tibbles (input as `list()`) returned from convert_output.
If inputting a list of tibbles, the first tibble's reference point defined in `ref_line` is used to plot a reference line or calculate relative spawning biomass.
Character vector. Abbreviated unit label for each quantity
Default: c("catch" = "mt", "spawning_biomass" = "mt", "fishing_mortality" = "")
Logical. TRUE/FALSE; indicate whether the environment is interactive.
Default: `FALSE`
Character vector. (Optional) Module name found in `dat$module_name`. If selecting >1 module, place them in a vector like c("module1", "module2").
Default: NULL
If the interactive and >1 module_name is found, user will select the module_name in the console. @seealso [filter_data()]
Logical. TRUE/FALSE; indicate whether to save the object and make an automated caption and alternative text in the form of an `rda` object. If TRUE, the rda will be exported to the folder indicated in the argument "figures_dir".
Default: `FALSE`.
Path. The location of the folder containing the generated table rda files ("tables") that will be created if the argument `make_rda` = TRUE.
Default: the working directory (`getwd()`)
A formatted gt table object.
We would like to thank Dan Hennen for sharing his projections table function code, which served as the foundation for this function.
table_projections(
dat = stockplotr::example_data,
interactive = FALSE,
module = "DERIVED_QUANTITIES")
#> ℹ Processing catch
#> ℹ Processing spawning_biomass
#> ℹ Processing fishing_mortality